@@ -1,5 +1,10 @@
 #include "MatrixExtra.h"
 
+#ifdef __clang__
+#   pragma clang diagnostic push
+#   pragma clang diagnostic ignored "-Wpass-failed"
+#endif
+
 size_t get_size_reserve(size_t nnz, size_t take1, size_t take2)
 {
     if (sizeof(size_t) < sizeof(uint64_t))
@@ -152,7 +157,9 @@ void reverse_columns_inplace
     {
         if (indptr[row] < indptr[row+1])
         {
+            #ifdef _OPENMP
             #pragma omp simd
+            #endif
             for (int ix = indptr[row]; ix < indptr[row+1]; ix++)
                 indices[ix] = ncol - indices[ix] - 1;
             std::reverse(indices + indptr[row], indices + indptr[row+1]);
@@ -634,12 +641,16 @@ Rcpp::IntegerVector repeat_indices_n_times(Rcpp::IntegerVector indices,
     Rcpp::IntegerVector out(n_indices*full_repeats + remainder.size());
     for (int repetition = 0; repetition < full_repeats; repetition++)
     {
+        #ifdef _OPENMP
         #pragma omp simd
+        #endif
         for (int ix = 0; ix < n_indices; ix++)
             out[ix + n_indices*repetition] = indices[ix] + ix_length*repetition;
     }
     
+    #ifdef _OPENMP
     #pragma omp simd
+    #endif
     for (int ix = 0; ix < remainder.size(); ix++)
         out[ix + n_indices*full_repeats] = remainder[ix] + ix_length*full_repeats;
     return out;
@@ -770,3 +781,7 @@ double extract_single_val_csr_binary
         row, col, false
     );
 }
+
+#ifdef __clang__
+#   pragma clang diagnostic pop
+#endif
